==> haskell-fmlist-0.9.4-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fmlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fmlist
version:              0.9.4
visibility:           public
id:                   fmlist-0.9.4-8bpLqUePgN09k8x4ia8meY
key:                  fmlist-0.9.4-8bpLqUePgN09k8x4ia8meY
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher
homepage:             https://github.com/sjoerdvisscher/fmlist
synopsis:             FoldMap lists
description:
    FoldMap lists are lists represented by their foldMap function.
    FoldMap lists have O(1) cons, snoc and append, just like DLists,
    but other operations might have favorable performance
    characteristics as well. These wild claims are still completely
    unverified though.

category:             Data
abi:                  1153dbc0a8c45448fe8547e6e01baf00
exposed:              True
exposed-modules:      Data.FMList
import-dirs:          /usr/lib/ghc-9.0.1/site-local/fmlist-0.9.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/fmlist-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/fmlist-0.9.4
hs-libraries:         HSfmlist-0.9.4-8bpLqUePgN09k8x4ia8meY
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-fmlist/html/fmlist.haddock
haddock-html:         /usr/share/doc/haskell-fmlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fmlist-0.9.4-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fmlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fmlist
version:              0.9.4
visibility:           public
id:                   fmlist-0.9.4-5YEANFYAIh6LJ1NuRjQBv2
key:                  fmlist-0.9.4-5YEANFYAIh6LJ1NuRjQBv2
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher
homepage:             https://github.com/sjoerdvisscher/fmlist
synopsis:             FoldMap lists
description:
    FoldMap lists are lists represented by their foldMap function.
    FoldMap lists have O(1) cons, snoc and append, just like DLists,
    but other operations might have favorable performance
    characteristics as well. These wild claims are still completely
    unverified though.

category:             Data
abi:                  a5aa259a3f60dfd28f41bccd29f071da
exposed:              True
exposed-modules:      Data.FMList
import-dirs:          /usr/lib/ghc-9.0.2/site-local/fmlist-0.9.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fmlist-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/fmlist-0.9.4
hs-libraries:         HSfmlist-0.9.4-5YEANFYAIh6LJ1NuRjQBv2
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-fmlist/html/fmlist.haddock
haddock-html:         /usr/share/doc/haskell-fmlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
